@@ -5,22 +5,22 @@ use strict;
 use Carp;
 use NetAddr::IP;
 use Net::IPTrie::Node;
-use vars qw($VERSION);
-$VERSION = '0.5.1';
+
+use version; our $VERSION = qv('0.1');
 
 1;
 
 =head1 NAME
 
-Net::IPTrie - Perl module for building IPv4 and IPv6 address space hierarchies
+Net::IPTrie - Perl module for building IPv4 and IPv6 address space hierarchies fast
 
 =head1 SYNOPSIS
 
     use Net::IPTrie;
     my $tr = Net::IPTrie->new(version=>4);  # IPv4
-    my $n  = $tr->add(address=>'10.0.0.0', prefix=>8);
-    my $a  = $tr->add(address=>'10.0.0.1', data=>$data) # prefix defaults to 32
-    $a->parent->address eq $n->address and print "$a is within $n";
+    my $n  = $tr->add(addres=>'10.0.0.0/8', prefix=>8);
+    my $a  = $tr->add(address=>'10.0.0.1', data) # prefix defaults to 32
+    $a->parent->address eq $n->address or die "?";
 
     # Addresses can be provided in integer (decimal) format
     # 10.0.0.7 == 167772167
@@ -40,7 +40,8 @@ Net::IPTrie - Perl module for building IPv4 and IPv6 address space hierarchies
  It is implemented exclusively in Perl.
 
 =head1 CLASS METHODS
-
+=cut
+############################################################################
 =head2 new - Class Constructor
 
 
@@ -53,7 +54,6 @@ Net::IPTrie - Perl module for building IPv4 and IPv6 address space hierarchies
     my $tr = Net::IPTrie->new(version=>4);
 
 =cut
-
 sub new {
     my ($proto, %argv) = @_;
     croak "Missing required parameters: version" unless defined $argv{version};
@@ -74,10 +74,9 @@ sub new {
     return $self;
 }
 
-############################################################################
-
 =head1 INSTANCE METHODS
-
+=cut
+############################################################################
 =head2 version - Set or get IP version (4 or 6)
 
   Arguments: 
@@ -88,7 +87,6 @@ sub new {
     print $tr->version;
 
 =cut
-
 sub version { 
     my ($self, $v) = @_;
     croak "version is an instance method" unless ref($self);
@@ -98,7 +96,6 @@ sub version {
 }
 
 ############################################################################
-
 =head2 size - Set or get IP size (32 or 128)
 
   Arguments:   
@@ -109,7 +106,6 @@ sub version {
     print $tr->size;   
 
 =cut
-
 sub size { 
     my ($self, $s) = @_;
     croak "size is an instance method" unless ref($self);
@@ -118,7 +114,6 @@ sub size {
 }
 
 ############################################################################
-
 =head2 find - Find an IP object in the trie
 
     If the given IP does not exist, there are two options:
@@ -139,21 +134,19 @@ sub size {
     my $n = $tr->find("10.0.0.1", 32);
 
 =cut
-
 sub find {
     my ($self, %argv) = @_;
     croak "find is an instance method" unless ref($self);
 
     my ($address, $iaddress, $prefix, $deep) = @argv{'address', 'iaddress', 'prefix', 'deep'};
-    croak "Missing required arguments: address or iaddress" 
-	unless (defined $address || defined $iaddress);
+    croak "Missing required arguments: address or iaddress" unless ($address || $iaddress);
     
-    $prefix = $self->size unless ( defined $prefix );
+    $prefix = $self->size unless ( $prefix );
     my $p   = $self->{_trie};   # pointer that starts at the root
     my $bit = $self->size;      # Start at the most significant bit
 
     # Convert string address into integer if necessary
-    if ( defined $address && !defined $iaddress ){
+    if ( $address && !$iaddress ){
 	$iaddress = $self->_ip2int($address);
     }
 
@@ -164,38 +157,34 @@ sub find {
 	my $r = ($iaddress & 2**$bit) == 0 ? 'left' : 'right';
 	
 	if ( !defined $p->$r ){
-	    if ( $deep ){
-		# Insert new node
-		$p->$r(Net::IPTrie::Node->new(up=>$p));
-	    }else{
+	    if ( !$deep ){
 		# Just return the closest covering IP block
 		if ( $p->iaddress ){
 		    return $p;
 		}else{
 		    return $p->parent;
 		}
+	    }else{
+		# Insert new node
+		$p->$r(Net::IPTrie::Node->new(up=>$p));
 	    }
 	}
 	
 	# Walk one step down the tree
 	$p = $p->$r;
 
-	if ( defined $p->iaddress ){
-	    # If the address matches, return node
-	    if ( $p->iaddress == $iaddress && $p->prefix == $prefix ){
-		return $p;
-	    }
-	}elsif ( !$deep && ($bit == $self->size - $prefix) ){
-	    # This is a deleted node
-	    return $p->parent;
+	# If the address matches, return node
+	if ( $p->iaddress && $p->iaddress == $iaddress 
+	     && $p->prefix == $prefix ){
+	    return $p;
 	}
     }
     # We fell off the bottom.  We tell where to create a new node.
     return $p;
 }
 
-############################################################################
 
+############################################################################
 =head2 add - Add an IP to the trie
 
   Arguments: 
@@ -210,27 +199,25 @@ sub find {
     my $n = $tr->add(address=>"10.0.0.1", prefix=>32, data=>\$data);
 
 =cut
-
 sub add {
     my ($self, %argv) = @_;
     croak "add is an instance method" unless ref($self);
 
     my ($address, $iaddress, $prefix, $data) = @argv{'address', 'iaddress', 'prefix', 'data'};
-    croak "Missing required arguments: address\n" 
-	unless ( defined $address || defined $iaddress );
+    croak "Missing required arguments: address" unless ( $address || $iaddress );
 
-    $prefix = $self->size unless ( defined $prefix );
+    $prefix = $self->size unless ( $prefix );
 
     # Convert string address into integer if necessary
-    if ( defined $address && !defined $iaddress ){
+    if ( $address && !$iaddress ){
 	$iaddress = $self->_ip2int($address);
-    }elsif ( defined $iaddress && !defined $address ){
+    }elsif ( $iaddress && !$address ){
 	$address = $self->_int2ip($iaddress);
     }
 
     my $n = $self->find(iaddress=>$iaddress, prefix=>$prefix, deep=>1);
     
-    unless ( defined $n->iaddress && $n->iaddress == $iaddress ){
+    unless ( $n->iaddress && $n->iaddress == $iaddress ){
 	$n->iaddress($iaddress);
 	$n->address($address);
 	$n->prefix($prefix);
@@ -256,7 +243,6 @@ sub add {
     my $count = $tr->traverse(code=>$code);
     
 =cut
-
 sub traverse {
     my ($self, %argv) = @_;
     croak "traverse is an instance method" unless ref($self);
@@ -273,7 +259,6 @@ sub traverse {
     return $count;
 }
 
-
 ############################################################################
 #
 # PRIVATE METHODS
@@ -354,16 +339,18 @@ sub _depth_first {
 
 =head1 AUTHOR
 
-Carlos Vicente  <cvicente@cpan.org>
+Carlos Vicente  C<< <<cvicente@cpan.org>> >>
 
 =head1 SEE ALSO
 
-Net::IPTrie::Node
-Net::Patricia 
+Net::Patricia
+
+Net::Patricia relies on a C library and currently does not support IPv6.  It also contains known bugs.
+I have not done any performance comparisons.
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2007-2010, Carlos Vicente <cvicente@cpan.org>. All rights reserved.
+Copyright (c) <2007-2010>, Carlos Vicente C<< <<cvicente@cpan.org>> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
