@@ -4,8 +4,8 @@ use warnings;
 use strict;
 use Carp;
 use Class::Struct;
-use vars qw($VERSION);
-$VERSION = '0.5.1';
+
+use version; our $VERSION = qv('0.1');
 
 =head1 NAME
 
@@ -22,7 +22,7 @@ Net::IPTrie::Node
 =cut
 
 struct (
-'up'        => '$',
+'up'      => '$',
 'left'      => '$',
 'right'     => '$',
 'address'   => '$',
@@ -47,13 +47,9 @@ struct (
     New Net::IPTrie::Node object
   Examples:
     my $n = Net::IPTrie::Node->new(up=>$up, address=>"10.0.0.1")
-
-=head1 INSTANCE METHODS
-
 =cut
 
 ############################################################################
-
 =head2 parent - Find closest parent node with IP information
 
   Arguments: 
@@ -64,19 +60,17 @@ struct (
     my $parent = $node->parent;
 
 =cut
-
 sub parent {
     my ($self) = @_;
 
     my $p = $self->up;
-    while ( defined $p && !defined $p->iaddress ){
+    while ( defined $p && !$p->iaddress ){
 	$p = $p->up;
     }
     return $p;
 }
 
 ############################################################################
-
 =head2 delete - Delete an IP node from the tree
 
   Note: The node is actually emptied, not deleted
@@ -90,7 +84,6 @@ sub parent {
    $n->delete();
 
 =cut
-
 sub delete {
     my ($self) = @_;
     $self->address(undef);
@@ -105,7 +98,7 @@ sub delete {
 
 =head1 AUTHOR
 
-Carlos Vicente  <cvicente@cpan.org>
+Carlos Vicente  C<< <<cvicente@cpan.org>> >>
 
 =head1 SEE ALSO
 
@@ -113,7 +106,7 @@ Carlos Vicente  <cvicente@cpan.org>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2007-2010, Carlos Vicente <cvicente@cpan.org>. All rights reserved.
+Copyright (c) <2007-2010>, Carlos Vicente C<< <<cvicente@cpan.org>> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
